"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const parser_js_1 = require("react-docgen-typescript/lib/parser.js");
const generateDocgenCodeBlock_1 = require("../generateDocgenCodeBlock");
function getGeneratorOptions(parserOptions = {}) {
    return (filename) => {
        const filePath = path_1.default.resolve(__dirname, "__fixtures__", filename);
        return {
            filename,
            source: fs_1.default.readFileSync(filePath, "utf8"),
            componentDocs: parser_js_1.parse(filePath, parserOptions),
            docgenCollectionName: null,
            setDisplayName: true,
            typePropName: "type",
        };
    };
}
function loadFixtureTests() {
    return fs_1.default
        .readdirSync(path_1.default.resolve(__dirname, "__fixtures__"))
        .map(getGeneratorOptions());
}
const fixtureTests = loadFixtureTests();
const simpleFixture = fixtureTests.find((f) => f.filename === "Simple.tsx");
describe("component fixture", () => {
    fixtureTests.forEach((generatorOptions) => {
        it(`${generatorOptions.filename} has code block generated`, () => {
            expect(generateDocgenCodeBlock_1.generateDocgenCodeBlock(generatorOptions)).toMatchSnapshot();
        });
    });
});
it("adds component to docgen collection", () => {
    expect(generateDocgenCodeBlock_1.generateDocgenCodeBlock(Object.assign(Object.assign({}, simpleFixture), { docgenCollectionName: "STORYBOOK_REACT_CLASSES" }))).toMatchSnapshot();
});
it("generates value info for enums", () => {
    expect(generateDocgenCodeBlock_1.generateDocgenCodeBlock(getGeneratorOptions({ shouldExtractLiteralValuesFromEnum: true })("DefaultPropValue.tsx"))).toMatchSnapshot();
});
//# sourceMappingURL=generateDocgenCodeBlock.test.js.map